==> gimp-2.3.3.tar.bz2: gimp-2.3.3/app/core/gimpimage-resize.h <==
/* The GIMP -- an image manipulation program
 * Copyright (C) 1995 Spencer Kimball and Peter Mattisbvf
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef __GIMP_IMAGE_RESIZE_H__
#define __GIMP_IMAGE_RESIZE_H__


void   gimp_image_resize             (GimpImage             *gimage,
                                      GimpContext           *context,
                                      gint                   new_width,
                                      gint                   new_height,
                                      gint                   offset_x,
                                      gint                   offset_y,
                                      GimpProgress          *progress);

void   gimp_image_resize_with_layers (GimpImage             *gimage,
                                      GimpContext           *context,
                                      gint                   new_width,
                                      gint                   new_height,
                                      gint                   offset_x,
                                      gint                   offset_y,
                                      GimpImageResizeLayers  resize_layers,
                                      GimpProgress          *progress);

void   gimp_image_resize_to_layers   (GimpImage             *gimage,
                                      GimpContext           *context,
                                      GimpProgress          *progress);


#endif /* __GIMP_IMAGE_RESIZE_H__ */

==> gimp-2.3.8.tar.bz2: gimp-2.3.8/app/core/gimpimage-resize.h <==
/* The GIMP -- an image manipulation program
 * Copyright (C) 1995 Spencer Kimball and Peter Mattisbvf
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef __GIMP_IMAGE_RESIZE_H__
#define __GIMP_IMAGE_RESIZE_H__


void   gimp_image_resize             (GimpImage             *image,
                                      GimpContext           *context,
                                      gint                   new_width,
                                      gint                   new_height,
                                      gint                   offset_x,
                                      gint                   offset_y,
                                      GimpProgress          *progress);

void   gimp_image_resize_with_layers (GimpImage             *image,
                                      GimpContext           *context,
                                      gint                   new_width,
                                      gint                   new_height,
                                      gint                   offset_x,
                                      gint                   offset_y,
                                      GimpImageResizeLayers  resize_layers,
                                      GimpProgress          *progress);

void   gimp_image_resize_to_layers   (GimpImage             *image,
                                      GimpContext           *context,
                                      GimpProgress          *progress);


#endif /* __GIMP_IMAGE_RESIZE_H__ */
